@@ -64,8 +64,8 @@ class irf_cta:
         self.energy = logbin_mean(self.energy_bins)
 
         # Area of CTA sites in meters
-        self.ParanalArea_prod3 = 19.63e6 * u.m ** 2
-        self.LaPalmaArea_prod3 = 11341149 * u.m ** 2  # 6.61e6
+        self.ParanalArea_prod3 = 19.63e6 * u.m**2
+        self.LaPalmaArea_prod3 = 11341149 * u.m**2  # 6.61e6
 
     @u.quantity_input(energy_bins=u.TeV)
     def set_ebin(self, energy_bins):
@@ -78,7 +78,7 @@ class cta_performance:
         self.site = site
         self.energy = np.empty(0) * u.TeV
         self.energy_bins = np.empty(0) * u.TeV
-        self.effective_area = np.empty(0) * u.m
+        self.effective_area = np.empty(0) * u.m**2
         self.angular_resolution = np.empty(0) * u.deg
         self.energy_resolution = np.empty(0)
         self.sensitivity = np.empty(0) * u.erg / (u.cm ** 2 * u.s)
@@ -103,13 +103,13 @@ class cta_performance:
                     ds.get('CTA-Performance-prod3b-v2-South-20deg-50h-EffArea.txt'),
                     skiprows=11, unpack=True)
                 self.energy = energy * u.TeV
-                self.effective_area = effective_area * u.m
+                self.effective_area = effective_area * u.m**2
             elif observation_time == 0.5 * u.h:
                 energy, effective_area = np.loadtxt(
                     ds.get('CTA-Performance-prod3b-v2-North-20deg-30m-EffArea.txt'),
                     skiprows=11, unpack=True)
                 self.energy = energy * u.TeV
-                self.effective_area = effective_area * u.m
+                self.effective_area = effective_area * u.m**2
             else:
                 raise ValueError("no effective area for this observation time")
 
@@ -119,13 +119,13 @@ class cta_performance:
                     ds.get('CTA-Performance-prod3b-v2-North-20deg-50h-EffArea.txt'),
                     skiprows=11, unpack=True)
                 self.energy = energy * u.TeV
-                self.effective_area = effective_area * u.m
+                self.effective_area = effective_area * u.m**2
             elif observation_time == 0.5 * u.h:
                 energy, effective_area = np.loadtxt(
                     ds.get('CTA-Performance-prod3b-v2-North-20deg-30m-EffArea.txt'),
                     skiprows=11, unpack=True)
                 self.energy = energy * u.TeV
-                self.effective_area = effective_area * u.m
+                self.effective_area = effective_area * u.m**2
             else:
                 raise ValueError("no effective area for this observation time")
 
@@ -203,7 +203,7 @@ class cta_requirement:
     def __init__(self, site):
         self.site = site
         self.energy = np.empty(0) * u.TeV
-        self.effective_area = np.empty(0) * u.m
+        self.effective_area = np.empty(0) * u.m**2
         self.angular_resolution = np.empty(0) * u.deg
         self.energy_resolution = np.empty(0)
         self.sensitivity = np.empty(0) * u.erg / (u.cm ** 2 * u.s)
@@ -235,7 +235,7 @@ class cta_requirement:
             raise ValueError(
                 f'incorrect site specified, accepted values are {_north_site_names} or {_south_site_names}')
         self.energy = energy * u.TeV
-        self.effective_area = effective_area * u.m
+        self.effective_area = effective_area * u.m**2
         return self.energy, self.effective_area
 
     def get_angular_resolution(self):
@@ -409,11 +409,11 @@ def relative_scaling(true, reco, method='s0'):
     There are different ways to calculate this scaling factor.
     The easiest and most spread one is simply `np.abs(true)`. However this is possible only when `true != 0`.
     Possible methods:
-        - None or 's0': scale = 1
-        - 's1': `scale = np.abs(true)`
-        - 's2': `scale = np.abs(reco)`
-        - 's3': `scale = (np.abs(true) + np.abs(reco))/2.`
-        - 's4': `scale = np.max([np.abs(reco), np.abs(true)], axis=0)`
+    - None or 's0': scale = 1
+    - 's1': `scale = np.abs(true)`
+    - 's2': `scale = np.abs(reco)`
+    - 's3': `scale = (np.abs(true) + np.abs(reco))/2.`
+    - 's4': `scale = np.max([np.abs(reco), np.abs(true)], axis=0)`
 
     This method is not exposed but kept for tests and future reference.
     The `s1` method is used in all `ctaplot` functions.
@@ -444,7 +444,7 @@ def resolution(true, reco,
     """
     Compute the resolution of reco as the Qth (68.27 as standard = 1 sigma) containment radius of
     `(true-reco)/relative_scaling` with the lower and upper confidence limits defined the values inside
-     the error_percentile
+    the error_percentile
 
     Parameters
     ----------
@@ -555,7 +555,7 @@ def resolution_per_energy(true, reco, true_energy, percentile=68.27, confidence_
 def energy_resolution(true_energy, reco_energy, percentile=68.27, confidence_level=0.95, bias_correction=False):
     """
     Compute the true_energy resolution of true_energy as the percentile (68 as standard) containment radius of
-    `true_energy-true_energy)/true_energy
+    `true_energy-true_energy)/true_energy`
     with the lower and upper confidence limits defined by the given confidence level
 
     Parameters
@@ -582,22 +582,25 @@ def energy_resolution_per_energy(true_energy, reco_energy,
     """
     The true_energy resolution ΔE / energy is obtained from the distribution of (ER – ET) / ET, where R and T refer
     to the reconstructed and true energy of gamma-ray events.
-     ΔE/energy is the half-width of the interval around 0 which contains given percentile of the distribution.
+    ΔE/energy is the half-width of the interval around 0 which contains given percentile of the distribution.
 
     Parameters
     ----------
-    true_energy: 1d numpy array of simulated energy
-    reco_energy: 1d numpy array of reconstructed energy
+    true_energy: `astropy.Quantity`
+        1d array of simulated energy
+    reco_energy: `astropy.Quantity`
+        1d array of reconstructed energy
     percentile: float
         between 0 and 100
     confidence_level: float
         between 0 and 1
     bias_correction: bool
-    bins: numpy array
+    bins: int | `astropy.Quantity`
 
     Returns
     -------
-    (e, e_res) : tuple of 1d numpy arrays - true_energy, resolution in true_energy
+    (e, e_res): (astropy.Quantity, numpy.array)
+        true_energy, resolution in true_energy
     """
     assert len(reco_energy) > 0, "Empty arrays"
 
@@ -629,12 +632,13 @@ def energy_bias(true_energy, reco_energy, bins=None):
         simulated energies
     reco_energy: `astropy.Quantity` (1d array)
         reconstructed energies
-    bins:`astropy.Quantity` (1d array)
+    bins: astropy.Quantity (1d array)
         energy bins - if None, standard CTA binning is used
 
     Returns
     -------
-    (energy_bins, bias) : tuple of 1d numpy arrays - true_energy, true_energy bias
+    (energy_bins, bias): (astropy.Quantity, numpy.array)
+        true_energy, true_energy bias
     """
     bias_e = []
 
@@ -692,7 +696,7 @@ def theta2(true_alt, reco_alt, true_az, reco_az, bias_correction=False):
 
     Returns
     -------
-    1d `numpy.ndarray`
+    theta2: `astropy.Quantity` (~deg2)
     """
     assert (len(reco_az) == len(reco_alt))
     assert (len(reco_alt) == len(true_alt))
@@ -717,10 +721,14 @@ def angular_resolution(true_alt, reco_alt, true_az, reco_az,
 
     Parameters
     ----------
-    reco_alt: `astropy.Quantity` - reconstructed altitude angle in radians
-    reco_az: `astropy.Quantity` - reconstructed azimuth angle in radians
-    true_alt: `astropy.Quantity` - true altitude angle in radians
-    true_az: `astropy.Quantity` - true azimuth angle in radians
+    reco_alt: `astropy.Quantity`
+        reconstructed altitude angle in radians
+    reco_az: `astropy.Quantity`
+        reconstructed azimuth angle in radians
+    true_alt: `astropy.Quantity`
+        true altitude angle in radians
+    true_az: `astropy.Quantity`
+        true azimuth angle in radians
     percentile: float - percentile, 68 corresponds to one sigma
     confidence_level: float
 
@@ -766,9 +774,7 @@ def angular_resolution_per_bin(true_alt, reco_alt, true_az, reco_az, x,
 
     Returns
     -------
-    bins, ang_res:
-        bins: 1D `numpy.ndarray`
-        ang_res: 2D `numpy.ndarray`
+    bins, ang_res: (numpy.ndarray, numpy.ndarray)
     """
     _, x_bins = np.histogram(x, bins=bins)
     bin_index = np.digitize(x, x_bins)
@@ -804,7 +810,7 @@ def angular_resolution_per_energy(true_alt, reco_alt, true_az, reco_az, energy,
 
     Returns
     -------
-    (energy, RES) : (1d numpy array, 1d numpy array) = Energies, Resolution
+    (energy, RES) : (astropy.Quantity, numpy.array)
     """
     if not len(reco_alt) == len(reco_az) == len(energy) > 0:
         raise ValueError("reco_alt, reco_az and true_energy must have the same length")
@@ -1048,7 +1054,7 @@ def impact_resolution_per_energy(true_x, reco_x, true_y, reco_y, true_energy,
 
     Returns
     -------
-    (true_energy, resolution) : (1d numpy array, 1d numpy array)
+    (true_energy, resolution) : (`astropy.Quantity`, 1d numpy array)
     """
     assert len(reco_x) == len(true_energy)
     assert len(true_energy) > 0, "Empty arrays"
@@ -1091,8 +1097,9 @@ def percentile_confidence_interval(x, percentile=68, confidence_level=0.95):
     if len(x) == 0:
         return 0, 0
     q = percentile / 100.
-    j = np.max([0, np.int(len(x) * q - z * np.sqrt(len(x) * q * (1 - q)))])
-    k = np.min([np.int(len(x) * q + z * np.sqrt(len(x) * q * (1 - q))), len(x) - 1])
+
+    j = np.max([0, int(len(x) * q - z * np.sqrt(len(x) * q * (1 - q)))])
+    k = np.min([int(len(x) * q + z * np.sqrt(len(x) * q * (1 - q))), len(x) - 1])
     return sorted_x[j], sorted_x[k]
 
 
